// $Id: VideoSystem.cc 8278 2008-10-01 17:10:24Z m9710797 $

#include "VideoSystem.hh"
#include "CommandException.hh"
#include <cassert>

namespace openmsx {

VideoSystem::~VideoSystem()
{
}

bool VideoSystem::checkSettings()
{
	return true;
}

void VideoSystem::prepare()
{
	// nothing
}

void VideoSystem::takeScreenShot(const std::string& /*filename*/)
{
	throw CommandException(
		"Taking screenshot not possible with current renderer.");
}

void VideoSystem::setWindowTitle(const std::string& /*title*/)
{
	// ignore
}

} // namespace openmsx
